# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BlockDeviceArgs', 'BlockDevice']

@pulumi.input_type
class BlockDeviceArgs:
    def __init__(__self__, *,
                 capacity_in_gb: pulumi.Input[int],
                 project_id: pulumi.Input[str],
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_content_base64: Optional[pulumi.Input[str]] = None,
                 encrypted: Optional[pulumi.Input[bool]] = None,
                 expand_snapshots: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 persistent: Optional[pulumi.Input[bool]] = None,
                 purge: Optional[pulumi.Input[bool]] = None,
                 source_reference: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]]] = None):
        """
        The set of arguments for constructing a BlockDevice resource.
        :param pulumi.Input[int] capacity_in_gb: Capacity of block device in GB.
        :param pulumi.Input[str] project_id: ID of project that current user belongs to.
        :param pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]] constraints: Storage, network, and extensibility constraints to be applied when provisioning through the project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: ID of deployment associated with resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] disk_content_base64: Content of a disk, base64 encoded.
        :param pulumi.Input[bool] encrypted: Indicates whether block device should be encrypted or not.
        :param pulumi.Input[bool] expand_snapshots: Indicates whether snapshots of block devices should be included in the state. Applies only to first class block devices.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[bool] persistent: Indicates whether block device survives a delete action.
        :param pulumi.Input[bool] purge: Indicates if the disk must be completely destroyed or should be kept in the system. Valid only for block devices with ‘persistent’ set to true. Used to destroy the resource.
        :param pulumi.Input[str] source_reference: URI to use for block device. Example: ami-0d4cfd66
        :param pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]] tags: Set of tag keys and values to apply to the resource instance.  
               Example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        pulumi.set(__self__, "capacity_in_gb", capacity_in_gb)
        pulumi.set(__self__, "project_id", project_id)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disk_content_base64 is not None:
            pulumi.set(__self__, "disk_content_base64", disk_content_base64)
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if expand_snapshots is not None:
            pulumi.set(__self__, "expand_snapshots", expand_snapshots)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if persistent is not None:
            pulumi.set(__self__, "persistent", persistent)
        if purge is not None:
            pulumi.set(__self__, "purge", purge)
        if source_reference is not None:
            pulumi.set(__self__, "source_reference", source_reference)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="capacityInGb")
    def capacity_in_gb(self) -> pulumi.Input[int]:
        """
        Capacity of block device in GB.
        """
        return pulumi.get(self, "capacity_in_gb")

    @capacity_in_gb.setter
    def capacity_in_gb(self, value: pulumi.Input[int]):
        pulumi.set(self, "capacity_in_gb", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        ID of project that current user belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]]]:
        """
        Storage, network, and extensibility constraints to be applied when provisioning through the project.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of deployment associated with resource.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diskContentBase64")
    def disk_content_base64(self) -> Optional[pulumi.Input[str]]:
        """
        Content of a disk, base64 encoded.
        """
        return pulumi.get(self, "disk_content_base64")

    @disk_content_base64.setter
    def disk_content_base64(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_content_base64", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether block device should be encrypted or not.
        """
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "encrypted", value)

    @property
    @pulumi.getter(name="expandSnapshots")
    def expand_snapshots(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether snapshots of block devices should be included in the state. Applies only to first class block devices.
        """
        return pulumi.get(self, "expand_snapshots")

    @expand_snapshots.setter
    def expand_snapshots(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_snapshots", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def persistent(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether block device survives a delete action.
        """
        return pulumi.get(self, "persistent")

    @persistent.setter
    def persistent(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "persistent", value)

    @property
    @pulumi.getter
    def purge(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the disk must be completely destroyed or should be kept in the system. Valid only for block devices with ‘persistent’ set to true. Used to destroy the resource.
        """
        return pulumi.get(self, "purge")

    @purge.setter
    def purge(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "purge", value)

    @property
    @pulumi.getter(name="sourceReference")
    def source_reference(self) -> Optional[pulumi.Input[str]]:
        """
        URI to use for block device. Example: ami-0d4cfd66
        """
        return pulumi.get(self, "source_reference")

    @source_reference.setter
    def source_reference(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_reference", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]]]:
        """
        Set of tag keys and values to apply to the resource instance.  
        Example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _BlockDeviceState:
    def __init__(__self__, *,
                 capacity_in_gb: Optional[pulumi.Input[int]] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_content_base64: Optional[pulumi.Input[str]] = None,
                 encrypted: Optional[pulumi.Input[bool]] = None,
                 expand_snapshots: Optional[pulumi.Input[bool]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 external_region_id: Optional[pulumi.Input[str]] = None,
                 external_zone_id: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 persistent: Optional[pulumi.Input[bool]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 purge: Optional[pulumi.Input[bool]] = None,
                 snapshots: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotArgs']]]] = None,
                 source_reference: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BlockDevice resources.
        :param pulumi.Input[int] capacity_in_gb: Capacity of block device in GB.
        :param pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]] constraints: Storage, network, and extensibility constraints to be applied when provisioning through the project.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: ID of deployment associated with resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] disk_content_base64: Content of a disk, base64 encoded.
        :param pulumi.Input[bool] encrypted: Indicates whether block device should be encrypted or not.
        :param pulumi.Input[bool] expand_snapshots: Indicates whether snapshots of block devices should be included in the state. Applies only to first class block devices.
        :param pulumi.Input[str] external_id: External entity ID on provider side.
        :param pulumi.Input[str] external_region_id: External regionId of resource.
        :param pulumi.Input[str] external_zone_id: External zoneId of resource.
        :param pulumi.Input[Sequence[pulumi.Input['BlockDeviceLinkArgs']]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that block device snapshot belongs to.
        :param pulumi.Input[str] owner: Email of block device snapshot owner.
        :param pulumi.Input[bool] persistent: Indicates whether block device survives a delete action.
        :param pulumi.Input[str] project_id: ID of project that current user belongs to.
        :param pulumi.Input[bool] purge: Indicates if the disk must be completely destroyed or should be kept in the system. Valid only for block devices with ‘persistent’ set to true. Used to destroy the resource.
        :param pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotArgs']]] snapshots: Represents a machine snapshot.
        :param pulumi.Input[str] source_reference: URI to use for block device. Example: ami-0d4cfd66
        :param pulumi.Input[str] status: Status of block device.
        :param pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]] tags: Set of tag keys and values to apply to the resource instance.  
               Example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        if capacity_in_gb is not None:
            pulumi.set(__self__, "capacity_in_gb", capacity_in_gb)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disk_content_base64 is not None:
            pulumi.set(__self__, "disk_content_base64", disk_content_base64)
        if encrypted is not None:
            pulumi.set(__self__, "encrypted", encrypted)
        if expand_snapshots is not None:
            pulumi.set(__self__, "expand_snapshots", expand_snapshots)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if external_region_id is not None:
            pulumi.set(__self__, "external_region_id", external_region_id)
        if external_zone_id is not None:
            pulumi.set(__self__, "external_zone_id", external_zone_id)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if persistent is not None:
            pulumi.set(__self__, "persistent", persistent)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if purge is not None:
            pulumi.set(__self__, "purge", purge)
        if snapshots is not None:
            pulumi.set(__self__, "snapshots", snapshots)
        if source_reference is not None:
            pulumi.set(__self__, "source_reference", source_reference)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="capacityInGb")
    def capacity_in_gb(self) -> Optional[pulumi.Input[int]]:
        """
        Capacity of block device in GB.
        """
        return pulumi.get(self, "capacity_in_gb")

    @capacity_in_gb.setter
    def capacity_in_gb(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "capacity_in_gb", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]]]:
        """
        Storage, network, and extensibility constraints to be applied when provisioning through the project.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceConstraintArgs']]]]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of deployment associated with resource.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "deployment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="diskContentBase64")
    def disk_content_base64(self) -> Optional[pulumi.Input[str]]:
        """
        Content of a disk, base64 encoded.
        """
        return pulumi.get(self, "disk_content_base64")

    @disk_content_base64.setter
    def disk_content_base64(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_content_base64", value)

    @property
    @pulumi.getter
    def encrypted(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether block device should be encrypted or not.
        """
        return pulumi.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "encrypted", value)

    @property
    @pulumi.getter(name="expandSnapshots")
    def expand_snapshots(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether snapshots of block devices should be included in the state. Applies only to first class block devices.
        """
        return pulumi.get(self, "expand_snapshots")

    @expand_snapshots.setter
    def expand_snapshots(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "expand_snapshots", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        External entity ID on provider side.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        External regionId of resource.
        """
        return pulumi.get(self, "external_region_id")

    @external_region_id.setter
    def external_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_region_id", value)

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        External zoneId of resource.
        """
        return pulumi.get(self, "external_zone_id")

    @external_zone_id.setter
    def external_zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_zone_id", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceLinkArgs']]]]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that block device snapshot belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of block device snapshot owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def persistent(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether block device survives a delete action.
        """
        return pulumi.get(self, "persistent")

    @persistent.setter
    def persistent(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "persistent", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of project that current user belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def purge(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the disk must be completely destroyed or should be kept in the system. Valid only for block devices with ‘persistent’ set to true. Used to destroy the resource.
        """
        return pulumi.get(self, "purge")

    @purge.setter
    def purge(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "purge", value)

    @property
    @pulumi.getter
    def snapshots(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotArgs']]]]:
        """
        Represents a machine snapshot.
        """
        return pulumi.get(self, "snapshots")

    @snapshots.setter
    def snapshots(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceSnapshotArgs']]]]):
        pulumi.set(self, "snapshots", value)

    @property
    @pulumi.getter(name="sourceReference")
    def source_reference(self) -> Optional[pulumi.Input[str]]:
        """
        URI to use for block device. Example: ami-0d4cfd66
        """
        return pulumi.get(self, "source_reference")

    @source_reference.setter
    def source_reference(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_reference", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of block device.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]]]:
        """
        Set of tag keys and values to apply to the resource instance.  
        Example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BlockDeviceTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class BlockDevice(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity_in_gb: Optional[pulumi.Input[int]] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceConstraintArgs']]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_content_base64: Optional[pulumi.Input[str]] = None,
                 encrypted: Optional[pulumi.Input[bool]] = None,
                 expand_snapshots: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 persistent: Optional[pulumi.Input[bool]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 purge: Optional[pulumi.Input[bool]] = None,
                 source_reference: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceTagArgs']]]]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation block device resource.

        ## Example Usage
        ### S

        The following example shows how to create a block device resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        disk1 = vra.blockdevice.BlockDevice("disk1",
            capacity_in_gb=10,
            project_id=var["project_id"],
            persistent=True)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] capacity_in_gb: Capacity of block device in GB.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceConstraintArgs']]]] constraints: Storage, network, and extensibility constraints to be applied when provisioning through the project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: ID of deployment associated with resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] disk_content_base64: Content of a disk, base64 encoded.
        :param pulumi.Input[bool] encrypted: Indicates whether block device should be encrypted or not.
        :param pulumi.Input[bool] expand_snapshots: Indicates whether snapshots of block devices should be included in the state. Applies only to first class block devices.
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[bool] persistent: Indicates whether block device survives a delete action.
        :param pulumi.Input[str] project_id: ID of project that current user belongs to.
        :param pulumi.Input[bool] purge: Indicates if the disk must be completely destroyed or should be kept in the system. Valid only for block devices with ‘persistent’ set to true. Used to destroy the resource.
        :param pulumi.Input[str] source_reference: URI to use for block device. Example: ami-0d4cfd66
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceTagArgs']]]] tags: Set of tag keys and values to apply to the resource instance.  
               Example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BlockDeviceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation block device resource.

        ## Example Usage
        ### S

        The following example shows how to create a block device resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        disk1 = vra.blockdevice.BlockDevice("disk1",
            capacity_in_gb=10,
            project_id=var["project_id"],
            persistent=True)
        ```

        :param str resource_name: The name of the resource.
        :param BlockDeviceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BlockDeviceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity_in_gb: Optional[pulumi.Input[int]] = None,
                 constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceConstraintArgs']]]]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 deployment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disk_content_base64: Optional[pulumi.Input[str]] = None,
                 encrypted: Optional[pulumi.Input[bool]] = None,
                 expand_snapshots: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 persistent: Optional[pulumi.Input[bool]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 purge: Optional[pulumi.Input[bool]] = None,
                 source_reference: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BlockDeviceArgs.__new__(BlockDeviceArgs)

            if capacity_in_gb is None and not opts.urn:
                raise TypeError("Missing required property 'capacity_in_gb'")
            __props__.__dict__["capacity_in_gb"] = capacity_in_gb
            __props__.__dict__["constraints"] = constraints
            __props__.__dict__["custom_properties"] = custom_properties
            __props__.__dict__["deployment_id"] = deployment_id
            __props__.__dict__["description"] = description
            __props__.__dict__["disk_content_base64"] = disk_content_base64
            __props__.__dict__["encrypted"] = encrypted
            __props__.__dict__["expand_snapshots"] = expand_snapshots
            __props__.__dict__["name"] = name
            __props__.__dict__["persistent"] = persistent
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["purge"] = purge
            __props__.__dict__["source_reference"] = source_reference
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["external_id"] = None
            __props__.__dict__["external_region_id"] = None
            __props__.__dict__["external_zone_id"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["snapshots"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(BlockDevice, __self__).__init__(
            'vra:blockdevice/blockDevice:BlockDevice',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacity_in_gb: Optional[pulumi.Input[int]] = None,
            constraints: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceConstraintArgs']]]]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            deployment_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            disk_content_base64: Optional[pulumi.Input[str]] = None,
            encrypted: Optional[pulumi.Input[bool]] = None,
            expand_snapshots: Optional[pulumi.Input[bool]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            external_region_id: Optional[pulumi.Input[str]] = None,
            external_zone_id: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            persistent: Optional[pulumi.Input[bool]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            purge: Optional[pulumi.Input[bool]] = None,
            snapshots: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceSnapshotArgs']]]]] = None,
            source_reference: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'BlockDevice':
        """
        Get an existing BlockDevice resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] capacity_in_gb: Capacity of block device in GB.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceConstraintArgs']]]] constraints: Storage, network, and extensibility constraints to be applied when provisioning through the project.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: Additional custom properties that may be used to extend the machine.
        :param pulumi.Input[str] deployment_id: ID of deployment associated with resource.
        :param pulumi.Input[str] description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param pulumi.Input[str] disk_content_base64: Content of a disk, base64 encoded.
        :param pulumi.Input[bool] encrypted: Indicates whether block device should be encrypted or not.
        :param pulumi.Input[bool] expand_snapshots: Indicates whether snapshots of block devices should be included in the state. Applies only to first class block devices.
        :param pulumi.Input[str] external_id: External entity ID on provider side.
        :param pulumi.Input[str] external_region_id: External regionId of resource.
        :param pulumi.Input[str] external_zone_id: External zoneId of resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceLinkArgs']]]] links: HATEOAS of the entity
        :param pulumi.Input[str] name: Human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] org_id: ID of organization that block device snapshot belongs to.
        :param pulumi.Input[str] owner: Email of block device snapshot owner.
        :param pulumi.Input[bool] persistent: Indicates whether block device survives a delete action.
        :param pulumi.Input[str] project_id: ID of project that current user belongs to.
        :param pulumi.Input[bool] purge: Indicates if the disk must be completely destroyed or should be kept in the system. Valid only for block devices with ‘persistent’ set to true. Used to destroy the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceSnapshotArgs']]]] snapshots: Represents a machine snapshot.
        :param pulumi.Input[str] source_reference: URI to use for block device. Example: ami-0d4cfd66
        :param pulumi.Input[str] status: Status of block device.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['BlockDeviceTagArgs']]]] tags: Set of tag keys and values to apply to the resource instance.  
               Example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BlockDeviceState.__new__(_BlockDeviceState)

        __props__.__dict__["capacity_in_gb"] = capacity_in_gb
        __props__.__dict__["constraints"] = constraints
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["deployment_id"] = deployment_id
        __props__.__dict__["description"] = description
        __props__.__dict__["disk_content_base64"] = disk_content_base64
        __props__.__dict__["encrypted"] = encrypted
        __props__.__dict__["expand_snapshots"] = expand_snapshots
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["external_region_id"] = external_region_id
        __props__.__dict__["external_zone_id"] = external_zone_id
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["persistent"] = persistent
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["purge"] = purge
        __props__.__dict__["snapshots"] = snapshots
        __props__.__dict__["source_reference"] = source_reference
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return BlockDevice(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="capacityInGb")
    def capacity_in_gb(self) -> pulumi.Output[int]:
        """
        Capacity of block device in GB.
        """
        return pulumi.get(self, "capacity_in_gb")

    @property
    @pulumi.getter
    def constraints(self) -> pulumi.Output[Optional[Sequence['outputs.BlockDeviceConstraint']]]:
        """
        Storage, network, and extensibility constraints to be applied when provisioning through the project.
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Output[str]:
        """
        ID of deployment associated with resource.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskContentBase64")
    def disk_content_base64(self) -> pulumi.Output[Optional[str]]:
        """
        Content of a disk, base64 encoded.
        """
        return pulumi.get(self, "disk_content_base64")

    @property
    @pulumi.getter
    def encrypted(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether block device should be encrypted or not.
        """
        return pulumi.get(self, "encrypted")

    @property
    @pulumi.getter(name="expandSnapshots")
    def expand_snapshots(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether snapshots of block devices should be included in the state. Applies only to first class block devices.
        """
        return pulumi.get(self, "expand_snapshots")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[str]:
        """
        External entity ID on provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> pulumi.Output[str]:
        """
        External regionId of resource.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> pulumi.Output[str]:
        """
        External zoneId of resource.
        """
        return pulumi.get(self, "external_zone_id")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.BlockDeviceLink']]:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that block device snapshot belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of block device snapshot owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def persistent(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether block device survives a delete action.
        """
        return pulumi.get(self, "persistent")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        ID of project that current user belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def purge(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates if the disk must be completely destroyed or should be kept in the system. Valid only for block devices with ‘persistent’ set to true. Used to destroy the resource.
        """
        return pulumi.get(self, "purge")

    @property
    @pulumi.getter
    def snapshots(self) -> pulumi.Output[Sequence['outputs.BlockDeviceSnapshot']]:
        """
        Represents a machine snapshot.
        """
        return pulumi.get(self, "snapshots")

    @property
    @pulumi.getter(name="sourceReference")
    def source_reference(self) -> pulumi.Output[Optional[str]]:
        """
        URI to use for block device. Example: ami-0d4cfd66
        """
        return pulumi.get(self, "source_reference")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Status of block device.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.BlockDeviceTag']]:
        """
        Set of tag keys and values to apply to the resource instance.  
        Example:[ { "key" : "vmware.enumeration.type", "value": "nebs_block" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'LoadBalancerLink',
    'LoadBalancerNic',
    'LoadBalancerRoute',
    'LoadBalancerRouteHealthCheckConfiguration',
    'LoadBalancerTag',
    'LoadBalancerTarget',
]

@pulumi.output_type
class LoadBalancerLink(dict):
    def __init__(__self__, *,
                 rel: str,
                 href: Optional[str] = None,
                 hrefs: Optional[Sequence[str]] = None):
        pulumi.set(__self__, "rel", rel)
        if href is not None:
            pulumi.set(__self__, "href", href)
        if hrefs is not None:
            pulumi.set(__self__, "hrefs", hrefs)

    @property
    @pulumi.getter
    def rel(self) -> str:
        return pulumi.get(self, "rel")

    @property
    @pulumi.getter
    def href(self) -> Optional[str]:
        return pulumi.get(self, "href")

    @property
    @pulumi.getter
    def hrefs(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "hrefs")


@pulumi.output_type
class LoadBalancerNic(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "networkId":
            suggest = "network_id"
        elif key == "customProperties":
            suggest = "custom_properties"
        elif key == "deviceIndex":
            suggest = "device_index"
        elif key == "securityGroupIds":
            suggest = "security_group_ids"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in LoadBalancerNic. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        LoadBalancerNic.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        LoadBalancerNic.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 network_id: str,
                 addresses: Optional[Sequence[str]] = None,
                 custom_properties: Optional[Mapping[str, Any]] = None,
                 description: Optional[str] = None,
                 device_index: Optional[int] = None,
                 name: Optional[str] = None,
                 security_group_ids: Optional[Sequence[str]] = None):
        """
        :param Mapping[str, Any] custom_properties: Additional custom properties that may be used to extend the machine.
        :param str description: Describes machine within the scope of your organization and is not propagated to the cloud.
        :param str name: A human-friendly name used as an identifier in APIs that support this option.
        """
        pulumi.set(__self__, "network_id", network_id)
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if device_index is not None:
            pulumi.set(__self__, "device_index", device_index)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> str:
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter
    def addresses(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "addresses")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[Mapping[str, Any]]:
        """
        Additional custom properties that may be used to extend the machine.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        """
        Describes machine within the scope of your organization and is not propagated to the cloud.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="deviceIndex")
    def device_index(self) -> Optional[int]:
        return pulumi.get(self, "device_index")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "security_group_ids")


@pulumi.output_type
class LoadBalancerRoute(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "memberPort":
            suggest = "member_port"
        elif key == "memberProtocol":
            suggest = "member_protocol"
        elif key == "healthCheckConfigurations":
            suggest = "health_check_configurations"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in LoadBalancerRoute. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        LoadBalancerRoute.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        LoadBalancerRoute.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 member_port: str,
                 member_protocol: str,
                 port: str,
                 protocol: str,
                 health_check_configurations: Optional[Sequence['outputs.LoadBalancerRouteHealthCheckConfiguration']] = None):
        """
        :param str member_port: Member port where the traffic is routed to.
        :param str member_protocol: The protocol of the member traffic.
        :param str port: Port which the load balancer is listening to.
        :param str protocol: The protocol of the incoming load balancer requests.
        :param Sequence['LoadBalancerRouteHealthCheckConfigurationArgs'] health_check_configurations: Load balancer health check configuration.
        """
        pulumi.set(__self__, "member_port", member_port)
        pulumi.set(__self__, "member_protocol", member_protocol)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if health_check_configurations is not None:
            pulumi.set(__self__, "health_check_configurations", health_check_configurations)

    @property
    @pulumi.getter(name="memberPort")
    def member_port(self) -> str:
        """
        Member port where the traffic is routed to.
        """
        return pulumi.get(self, "member_port")

    @property
    @pulumi.getter(name="memberProtocol")
    def member_protocol(self) -> str:
        """
        The protocol of the member traffic.
        """
        return pulumi.get(self, "member_protocol")

    @property
    @pulumi.getter
    def port(self) -> str:
        """
        Port which the load balancer is listening to.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def protocol(self) -> str:
        """
        The protocol of the incoming load balancer requests.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="healthCheckConfigurations")
    def health_check_configurations(self) -> Optional[Sequence['outputs.LoadBalancerRouteHealthCheckConfiguration']]:
        """
        Load balancer health check configuration.
        """
        return pulumi.get(self, "health_check_configurations")


@pulumi.output_type
class LoadBalancerRouteHealthCheckConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "healthyThreshold":
            suggest = "healthy_threshold"
        elif key == "intervalSeconds":
            suggest = "interval_seconds"
        elif key == "timeoutSeconds":
            suggest = "timeout_seconds"
        elif key == "unhealthyThreshold":
            suggest = "unhealthy_threshold"
        elif key == "urlPath":
            suggest = "url_path"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in LoadBalancerRouteHealthCheckConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        LoadBalancerRouteHealthCheckConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        LoadBalancerRouteHealthCheckConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 port: str,
                 protocol: str,
                 healthy_threshold: Optional[int] = None,
                 interval_seconds: Optional[int] = None,
                 timeout_seconds: Optional[int] = None,
                 unhealthy_threshold: Optional[int] = None,
                 url_path: Optional[str] = None):
        """
        :param str port: Port which the load balancer is listening to.
        :param str protocol: The protocol of the incoming load balancer requests.
        :param int healthy_threshold: Number of consecutive successful checks before considering a particular back-end instance as healthy.
        :param int interval_seconds: Interval (in seconds) at which the health checks will be performed.
        :param int timeout_seconds: Timeout (in seconds) to wait for a response from the back-end instance.
        """
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "protocol", protocol)
        if healthy_threshold is not None:
            pulumi.set(__self__, "healthy_threshold", healthy_threshold)
        if interval_seconds is not None:
            pulumi.set(__self__, "interval_seconds", interval_seconds)
        if timeout_seconds is not None:
            pulumi.set(__self__, "timeout_seconds", timeout_seconds)
        if unhealthy_threshold is not None:
            pulumi.set(__self__, "unhealthy_threshold", unhealthy_threshold)
        if url_path is not None:
            pulumi.set(__self__, "url_path", url_path)

    @property
    @pulumi.getter
    def port(self) -> str:
        """
        Port which the load balancer is listening to.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def protocol(self) -> str:
        """
        The protocol of the incoming load balancer requests.
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="healthyThreshold")
    def healthy_threshold(self) -> Optional[int]:
        """
        Number of consecutive successful checks before considering a particular back-end instance as healthy.
        """
        return pulumi.get(self, "healthy_threshold")

    @property
    @pulumi.getter(name="intervalSeconds")
    def interval_seconds(self) -> Optional[int]:
        """
        Interval (in seconds) at which the health checks will be performed.
        """
        return pulumi.get(self, "interval_seconds")

    @property
    @pulumi.getter(name="timeoutSeconds")
    def timeout_seconds(self) -> Optional[int]:
        """
        Timeout (in seconds) to wait for a response from the back-end instance.
        """
        return pulumi.get(self, "timeout_seconds")

    @property
    @pulumi.getter(name="unhealthyThreshold")
    def unhealthy_threshold(self) -> Optional[int]:
        return pulumi.get(self, "unhealthy_threshold")

    @property
    @pulumi.getter(name="urlPath")
    def url_path(self) -> Optional[str]:
        return pulumi.get(self, "url_path")


@pulumi.output_type
class LoadBalancerTag(dict):
    def __init__(__self__, *,
                 key: str,
                 value: str):
        """
        :param str key: Tag’s key.
        :param str value: Tag’s value.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Tag’s key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        Tag’s value.
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class LoadBalancerTarget(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "machineId":
            suggest = "machine_id"
        elif key == "networkInterfaceId":
            suggest = "network_interface_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in LoadBalancerTarget. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        LoadBalancerTarget.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        LoadBalancerTarget.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 machine_id: str,
                 network_interface_id: Optional[str] = None):
        pulumi.set(__self__, "machine_id", machine_id)
        if network_interface_id is not None:
            pulumi.set(__self__, "network_interface_id", network_interface_id)

    @property
    @pulumi.getter(name="machineId")
    def machine_id(self) -> str:
        return pulumi.get(self, "machine_id")

    @property
    @pulumi.getter(name="networkInterfaceId")
    def network_interface_id(self) -> Optional[str]:
        return pulumi.get(self, "network_interface_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEnumerationVmcResult',
    'AwaitableGetEnumerationVmcResult',
    'get_enumeration_vmc',
    'get_enumeration_vmc_output',
]

@pulumi.output_type
class GetEnumerationVmcResult:
    """
    A collection of values returned by getEnumerationVmc.
    """
    def __init__(__self__, accept_self_signed_cert=None, api_token=None, dc_id=None, id=None, nsx_hostname=None, regions=None, sddc_name=None, vcenter_hostname=None, vcenter_password=None, vcenter_username=None):
        if accept_self_signed_cert and not isinstance(accept_self_signed_cert, bool):
            raise TypeError("Expected argument 'accept_self_signed_cert' to be a bool")
        pulumi.set(__self__, "accept_self_signed_cert", accept_self_signed_cert)
        if api_token and not isinstance(api_token, str):
            raise TypeError("Expected argument 'api_token' to be a str")
        pulumi.set(__self__, "api_token", api_token)
        if dc_id and not isinstance(dc_id, str):
            raise TypeError("Expected argument 'dc_id' to be a str")
        pulumi.set(__self__, "dc_id", dc_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if nsx_hostname and not isinstance(nsx_hostname, str):
            raise TypeError("Expected argument 'nsx_hostname' to be a str")
        pulumi.set(__self__, "nsx_hostname", nsx_hostname)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if sddc_name and not isinstance(sddc_name, str):
            raise TypeError("Expected argument 'sddc_name' to be a str")
        pulumi.set(__self__, "sddc_name", sddc_name)
        if vcenter_hostname and not isinstance(vcenter_hostname, str):
            raise TypeError("Expected argument 'vcenter_hostname' to be a str")
        pulumi.set(__self__, "vcenter_hostname", vcenter_hostname)
        if vcenter_password and not isinstance(vcenter_password, str):
            raise TypeError("Expected argument 'vcenter_password' to be a str")
        pulumi.set(__self__, "vcenter_password", vcenter_password)
        if vcenter_username and not isinstance(vcenter_username, str):
            raise TypeError("Expected argument 'vcenter_username' to be a str")
        pulumi.set(__self__, "vcenter_username", vcenter_username)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> Optional[bool]:
        return pulumi.get(self, "accept_self_signed_cert")

    @property
    @pulumi.getter(name="apiToken")
    def api_token(self) -> str:
        return pulumi.get(self, "api_token")

    @property
    @pulumi.getter(name="dcId")
    def dc_id(self) -> Optional[str]:
        return pulumi.get(self, "dc_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nsxHostname")
    def nsx_hostname(self) -> str:
        return pulumi.get(self, "nsx_hostname")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of Region names to enable provisioning on. Example: northamerica-northeast1
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="sddcName")
    def sddc_name(self) -> str:
        return pulumi.get(self, "sddc_name")

    @property
    @pulumi.getter(name="vcenterHostname")
    def vcenter_hostname(self) -> str:
        return pulumi.get(self, "vcenter_hostname")

    @property
    @pulumi.getter(name="vcenterPassword")
    def vcenter_password(self) -> str:
        return pulumi.get(self, "vcenter_password")

    @property
    @pulumi.getter(name="vcenterUsername")
    def vcenter_username(self) -> str:
        return pulumi.get(self, "vcenter_username")


class AwaitableGetEnumerationVmcResult(GetEnumerationVmcResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnumerationVmcResult(
            accept_self_signed_cert=self.accept_self_signed_cert,
            api_token=self.api_token,
            dc_id=self.dc_id,
            id=self.id,
            nsx_hostname=self.nsx_hostname,
            regions=self.regions,
            sddc_name=self.sddc_name,
            vcenter_hostname=self.vcenter_hostname,
            vcenter_password=self.vcenter_password,
            vcenter_username=self.vcenter_username)


def get_enumeration_vmc(accept_self_signed_cert: Optional[bool] = None,
                        api_token: Optional[str] = None,
                        dc_id: Optional[str] = None,
                        nsx_hostname: Optional[str] = None,
                        sddc_name: Optional[str] = None,
                        vcenter_hostname: Optional[str] = None,
                        vcenter_password: Optional[str] = None,
                        vcenter_username: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnumerationVmcResult:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for VMC cloud account.

    **Region enumeration data source for VMC**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_vmc(accept_self_signed_cert=True,
        dc_id=var["vra_data_collector_id"],
        api_token=var["api_token"],
        sddc_name=var["sddc_name"],
        nsx_hostname=var["nsx_hostname"],
        vcenter_hostname=var["vcenter_hostname"],
        vcenter_password=var["vcenter_password"],
        vcenter_username=var["vcenter_username"])
    ```

    The region enumeration data source for VMC cloud account supports the following arguments:


    :param bool accept_self_signed_cert: Accept self signed certificate when connecting to vSphere. Example: false
    :param str api_token: API Token for the cloud account endpoint.
    :param str dc_id: ID of a data collector vm deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collectors.
    :param str nsx_hostname: The IP address of the NSX Manager server in the specified SDDC / FQDN.
    :param str sddc_name: Identifier of the on-premise SDDC to be used by this cloud account.
    :param str vcenter_hostname: The IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
    :param str vcenter_password: Password for the user used to authenticate with the cloud Account
    :param str vcenter_username: vCenter user name for the specified SDDC.The specified user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
    """
    __args__ = dict()
    __args__['acceptSelfSignedCert'] = accept_self_signed_cert
    __args__['apiToken'] = api_token
    __args__['dcId'] = dc_id
    __args__['nsxHostname'] = nsx_hostname
    __args__['sddcName'] = sddc_name
    __args__['vcenterHostname'] = vcenter_hostname
    __args__['vcenterPassword'] = vcenter_password
    __args__['vcenterUsername'] = vcenter_username
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:region/getEnumerationVmc:getEnumerationVmc', __args__, opts=opts, typ=GetEnumerationVmcResult).value

    return AwaitableGetEnumerationVmcResult(
        accept_self_signed_cert=__ret__.accept_self_signed_cert,
        api_token=__ret__.api_token,
        dc_id=__ret__.dc_id,
        id=__ret__.id,
        nsx_hostname=__ret__.nsx_hostname,
        regions=__ret__.regions,
        sddc_name=__ret__.sddc_name,
        vcenter_hostname=__ret__.vcenter_hostname,
        vcenter_password=__ret__.vcenter_password,
        vcenter_username=__ret__.vcenter_username)


@_utilities.lift_output_func(get_enumeration_vmc)
def get_enumeration_vmc_output(accept_self_signed_cert: Optional[pulumi.Input[Optional[bool]]] = None,
                               api_token: Optional[pulumi.Input[str]] = None,
                               dc_id: Optional[pulumi.Input[Optional[str]]] = None,
                               nsx_hostname: Optional[pulumi.Input[str]] = None,
                               sddc_name: Optional[pulumi.Input[str]] = None,
                               vcenter_hostname: Optional[pulumi.Input[str]] = None,
                               vcenter_password: Optional[pulumi.Input[str]] = None,
                               vcenter_username: Optional[pulumi.Input[str]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnumerationVmcResult]:
    """
    ## Example Usage
    ### S

    This is an example of how to lookup a region enumeration data source for VMC cloud account.

    **Region enumeration data source for VMC**
    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.region.get_enumeration_vmc(accept_self_signed_cert=True,
        dc_id=var["vra_data_collector_id"],
        api_token=var["api_token"],
        sddc_name=var["sddc_name"],
        nsx_hostname=var["nsx_hostname"],
        vcenter_hostname=var["vcenter_hostname"],
        vcenter_password=var["vcenter_password"],
        vcenter_username=var["vcenter_username"])
    ```

    The region enumeration data source for VMC cloud account supports the following arguments:


    :param bool accept_self_signed_cert: Accept self signed certificate when connecting to vSphere. Example: false
    :param str api_token: API Token for the cloud account endpoint.
    :param str dc_id: ID of a data collector vm deployed in the on premise infrastructure. Refer to the data-collector API to create or list data collectors.
    :param str nsx_hostname: The IP address of the NSX Manager server in the specified SDDC / FQDN.
    :param str sddc_name: Identifier of the on-premise SDDC to be used by this cloud account.
    :param str vcenter_hostname: The IP address or FQDN of the vCenter Server in the specified SDDC. The cloud proxy belongs on this vCenter.
    :param str vcenter_password: Password for the user used to authenticate with the cloud Account
    :param str vcenter_username: vCenter user name for the specified SDDC.The specified user requires CloudAdmin credentials. The user does not require CloudGlobalAdmin credentials.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProjectResult',
    'AwaitableGetProjectResult',
    'get_project',
    'get_project_output',
]

@pulumi.output_type
class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, administrator_roles=None, administrators=None, constraints=None, custom_properties=None, description=None, id=None, machine_naming_template=None, member_roles=None, members=None, name=None, operation_timeout=None, placement_policy=None, shared_resources=None, viewer_roles=None, viewers=None, zone_assignments=None):
        if administrator_roles and not isinstance(administrator_roles, list):
            raise TypeError("Expected argument 'administrator_roles' to be a list")
        pulumi.set(__self__, "administrator_roles", administrator_roles)
        if administrators and not isinstance(administrators, list):
            raise TypeError("Expected argument 'administrators' to be a list")
        pulumi.set(__self__, "administrators", administrators)
        if constraints and not isinstance(constraints, dict):
            raise TypeError("Expected argument 'constraints' to be a dict")
        pulumi.set(__self__, "constraints", constraints)
        if custom_properties and not isinstance(custom_properties, dict):
            raise TypeError("Expected argument 'custom_properties' to be a dict")
        pulumi.set(__self__, "custom_properties", custom_properties)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if machine_naming_template and not isinstance(machine_naming_template, str):
            raise TypeError("Expected argument 'machine_naming_template' to be a str")
        pulumi.set(__self__, "machine_naming_template", machine_naming_template)
        if member_roles and not isinstance(member_roles, list):
            raise TypeError("Expected argument 'member_roles' to be a list")
        pulumi.set(__self__, "member_roles", member_roles)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if operation_timeout and not isinstance(operation_timeout, int):
            raise TypeError("Expected argument 'operation_timeout' to be a int")
        pulumi.set(__self__, "operation_timeout", operation_timeout)
        if placement_policy and not isinstance(placement_policy, str):
            raise TypeError("Expected argument 'placement_policy' to be a str")
        pulumi.set(__self__, "placement_policy", placement_policy)
        if shared_resources and not isinstance(shared_resources, bool):
            raise TypeError("Expected argument 'shared_resources' to be a bool")
        pulumi.set(__self__, "shared_resources", shared_resources)
        if viewer_roles and not isinstance(viewer_roles, list):
            raise TypeError("Expected argument 'viewer_roles' to be a list")
        pulumi.set(__self__, "viewer_roles", viewer_roles)
        if viewers and not isinstance(viewers, list):
            raise TypeError("Expected argument 'viewers' to be a list")
        pulumi.set(__self__, "viewers", viewers)
        if zone_assignments and not isinstance(zone_assignments, list):
            raise TypeError("Expected argument 'zone_assignments' to be a list")
        pulumi.set(__self__, "zone_assignments", zone_assignments)

    @property
    @pulumi.getter(name="administratorRoles")
    def administrator_roles(self) -> Optional[Sequence['outputs.GetProjectAdministratorRoleResult']]:
        return pulumi.get(self, "administrator_roles")

    @property
    @pulumi.getter
    def administrators(self) -> Sequence[str]:
        return pulumi.get(self, "administrators")

    @property
    @pulumi.getter
    def constraints(self) -> Optional['outputs.GetProjectConstraintsResult']:
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[Mapping[str, Any]]:
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="machineNamingTemplate")
    def machine_naming_template(self) -> Optional[str]:
        return pulumi.get(self, "machine_naming_template")

    @property
    @pulumi.getter(name="memberRoles")
    def member_roles(self) -> Optional[Sequence['outputs.GetProjectMemberRoleResult']]:
        return pulumi.get(self, "member_roles")

    @property
    @pulumi.getter
    def members(self) -> Sequence[str]:
        return pulumi.get(self, "members")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="operationTimeout")
    def operation_timeout(self) -> Optional[int]:
        return pulumi.get(self, "operation_timeout")

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> Optional[str]:
        return pulumi.get(self, "placement_policy")

    @property
    @pulumi.getter(name="sharedResources")
    def shared_resources(self) -> bool:
        return pulumi.get(self, "shared_resources")

    @property
    @pulumi.getter(name="viewerRoles")
    def viewer_roles(self) -> Optional[Sequence['outputs.GetProjectViewerRoleResult']]:
        return pulumi.get(self, "viewer_roles")

    @property
    @pulumi.getter
    def viewers(self) -> Sequence[str]:
        return pulumi.get(self, "viewers")

    @property
    @pulumi.getter(name="zoneAssignments")
    def zone_assignments(self) -> Optional[Sequence['outputs.GetProjectZoneAssignmentResult']]:
        return pulumi.get(self, "zone_assignments")


class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            administrator_roles=self.administrator_roles,
            administrators=self.administrators,
            constraints=self.constraints,
            custom_properties=self.custom_properties,
            description=self.description,
            id=self.id,
            machine_naming_template=self.machine_naming_template,
            member_roles=self.member_roles,
            members=self.members,
            name=self.name,
            operation_timeout=self.operation_timeout,
            placement_policy=self.placement_policy,
            shared_resources=self.shared_resources,
            viewer_roles=self.viewer_roles,
            viewers=self.viewers,
            zone_assignments=self.zone_assignments)


def get_project(administrator_roles: Optional[Sequence[pulumi.InputType['GetProjectAdministratorRoleArgs']]] = None,
                administrators: Optional[Sequence[str]] = None,
                constraints: Optional[pulumi.InputType['GetProjectConstraintsArgs']] = None,
                custom_properties: Optional[Mapping[str, Any]] = None,
                description: Optional[str] = None,
                id: Optional[str] = None,
                machine_naming_template: Optional[str] = None,
                member_roles: Optional[Sequence[pulumi.InputType['GetProjectMemberRoleArgs']]] = None,
                members: Optional[Sequence[str]] = None,
                name: Optional[str] = None,
                operation_timeout: Optional[int] = None,
                placement_policy: Optional[str] = None,
                shared_resources: Optional[bool] = None,
                viewer_roles: Optional[Sequence[pulumi.InputType['GetProjectViewerRoleArgs']]] = None,
                viewers: Optional[Sequence[str]] = None,
                zone_assignments: Optional[Sequence[pulumi.InputType['GetProjectZoneAssignmentArgs']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectResult:
    """
    ## Example Usage
    ### S
    This is an example of how to create a project data source.

    **Project data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.project.get_project(id=vra_project["my-project"]["id"])
    ```

    **Project data source filter by name:**

    ```python
    import pulumi
    import pulumi_vra as vra

    test_project = vra.project.get_project(name=vra_project["my-project"]["name"])
    ```

    A project data source supports the following arguments:


    :param Sequence[pulumi.InputType['GetProjectAdministratorRoleArgs']] administrator_roles: Administrator users or groups associated with the project. Only administrators can manage project's configuration.
    :param Sequence[str] administrators: A list of administrator users associated with the project. Only administrators can manage project's configuration.
    :param pulumi.InputType['GetProjectConstraintsArgs'] constraints: A list of storage, network and extensibility constraints to be applied when provisioning through this project.
    :param Mapping[str, Any] custom_properties: The project custom properties which are added to all requests in this project.
    :param str description: A human-friendly description.
    :param str id: The id of the image profile instance.
    :param str machine_naming_template: The naming template to be used for resources provisioned in this project.
    :param Sequence[pulumi.InputType['GetProjectMemberRoleArgs']] member_roles: Member users or groups associated with the project.
    :param Sequence[str] members: A list of member users associated with the project.
    :param str name: A human-friendly name used as an identifier in APIs that support this option.
    :param int operation_timeout: The timeout that should be used for Blueprint operations and Provisioning tasks. The timeout is in seconds.
    :param str placement_policy: The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
    :param bool shared_resources: The id of the organization this entity belongs to.
    :param Sequence[pulumi.InputType['GetProjectViewerRoleArgs']] viewer_roles: Viewer users or groups associated with the project.
    :param Sequence[str] viewers: A list of viewer users associated with the project.
    :param Sequence[pulumi.InputType['GetProjectZoneAssignmentArgs']] zone_assignments: A list of configurations for zone assignment to a project.
    """
    __args__ = dict()
    __args__['administratorRoles'] = administrator_roles
    __args__['administrators'] = administrators
    __args__['constraints'] = constraints
    __args__['customProperties'] = custom_properties
    __args__['description'] = description
    __args__['id'] = id
    __args__['machineNamingTemplate'] = machine_naming_template
    __args__['memberRoles'] = member_roles
    __args__['members'] = members
    __args__['name'] = name
    __args__['operationTimeout'] = operation_timeout
    __args__['placementPolicy'] = placement_policy
    __args__['sharedResources'] = shared_resources
    __args__['viewerRoles'] = viewer_roles
    __args__['viewers'] = viewers
    __args__['zoneAssignments'] = zone_assignments
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:project/getProject:getProject', __args__, opts=opts, typ=GetProjectResult).value

    return AwaitableGetProjectResult(
        administrator_roles=__ret__.administrator_roles,
        administrators=__ret__.administrators,
        constraints=__ret__.constraints,
        custom_properties=__ret__.custom_properties,
        description=__ret__.description,
        id=__ret__.id,
        machine_naming_template=__ret__.machine_naming_template,
        member_roles=__ret__.member_roles,
        members=__ret__.members,
        name=__ret__.name,
        operation_timeout=__ret__.operation_timeout,
        placement_policy=__ret__.placement_policy,
        shared_resources=__ret__.shared_resources,
        viewer_roles=__ret__.viewer_roles,
        viewers=__ret__.viewers,
        zone_assignments=__ret__.zone_assignments)


@_utilities.lift_output_func(get_project)
def get_project_output(administrator_roles: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectAdministratorRoleArgs']]]]] = None,
                       administrators: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                       constraints: Optional[pulumi.Input[Optional[pulumi.InputType['GetProjectConstraintsArgs']]]] = None,
                       custom_properties: Optional[pulumi.Input[Optional[Mapping[str, Any]]]] = None,
                       description: Optional[pulumi.Input[Optional[str]]] = None,
                       id: Optional[pulumi.Input[Optional[str]]] = None,
                       machine_naming_template: Optional[pulumi.Input[Optional[str]]] = None,
                       member_roles: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectMemberRoleArgs']]]]] = None,
                       members: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                       name: Optional[pulumi.Input[Optional[str]]] = None,
                       operation_timeout: Optional[pulumi.Input[Optional[int]]] = None,
                       placement_policy: Optional[pulumi.Input[Optional[str]]] = None,
                       shared_resources: Optional[pulumi.Input[Optional[bool]]] = None,
                       viewer_roles: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectViewerRoleArgs']]]]] = None,
                       viewers: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                       zone_assignments: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetProjectZoneAssignmentArgs']]]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetProjectResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to create a project data source.

    **Project data source by its id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.project.get_project(id=vra_project["my-project"]["id"])
    ```

    **Project data source filter by name:**

    ```python
    import pulumi
    import pulumi_vra as vra

    test_project = vra.project.get_project(name=vra_project["my-project"]["name"])
    ```

    A project data source supports the following arguments:


    :param Sequence[pulumi.InputType['GetProjectAdministratorRoleArgs']] administrator_roles: Administrator users or groups associated with the project. Only administrators can manage project's configuration.
    :param Sequence[str] administrators: A list of administrator users associated with the project. Only administrators can manage project's configuration.
    :param pulumi.InputType['GetProjectConstraintsArgs'] constraints: A list of storage, network and extensibility constraints to be applied when provisioning through this project.
    :param Mapping[str, Any] custom_properties: The project custom properties which are added to all requests in this project.
    :param str description: A human-friendly description.
    :param str id: The id of the image profile instance.
    :param str machine_naming_template: The naming template to be used for resources provisioned in this project.
    :param Sequence[pulumi.InputType['GetProjectMemberRoleArgs']] member_roles: Member users or groups associated with the project.
    :param Sequence[str] members: A list of member users associated with the project.
    :param str name: A human-friendly name used as an identifier in APIs that support this option.
    :param int operation_timeout: The timeout that should be used for Blueprint operations and Provisioning tasks. The timeout is in seconds.
    :param str placement_policy: The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
    :param bool shared_resources: The id of the organization this entity belongs to.
    :param Sequence[pulumi.InputType['GetProjectViewerRoleArgs']] viewer_roles: Viewer users or groups associated with the project.
    :param Sequence[str] viewers: A list of viewer users associated with the project.
    :param Sequence[pulumi.InputType['GetProjectZoneAssignmentArgs']] zone_assignments: A list of configurations for zone assignment to a project.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AzureArgs', 'Azure']

@pulumi.input_type
class AzureArgs:
    def __init__(__self__, *,
                 application_id: pulumi.Input[str],
                 application_key: pulumi.Input[str],
                 regions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 subscription_id: pulumi.Input[str],
                 tenant_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]] = None):
        """
        The set of arguments for constructing a Azure resource.
        :param pulumi.Input[str] application_id: Azure Client Application ID.
        :param pulumi.Input[str] application_key: Azure Client Application Secret Key.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] subscription_id: Azure Subscription ID.
        :param pulumi.Input[str] tenant_id: Azure Tenant ID.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Name of Azure cloud account.
        :param pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        pulumi.set(__self__, "application_id", application_id)
        pulumi.set(__self__, "application_key", application_key)
        pulumi.set(__self__, "regions", regions)
        pulumi.set(__self__, "subscription_id", subscription_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Input[str]:
        """
        Azure Client Application ID.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter(name="applicationKey")
    def application_key(self) -> pulumi.Input[str]:
        """
        Azure Client Application Secret Key.
        """
        return pulumi.get(self, "application_key")

    @application_key.setter
    def application_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "application_key", value)

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> pulumi.Input[str]:
        """
        Azure Subscription ID.
        """
        return pulumi.get(self, "subscription_id")

    @subscription_id.setter
    def subscription_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "subscription_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[str]:
        """
        Azure Tenant ID.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Azure cloud account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _AzureState:
    def __init__(__self__, *,
                 application_id: Optional[pulumi.Input[str]] = None,
                 application_key: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subscription_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Azure resources.
        :param pulumi.Input[str] application_id: Azure Client Application ID.
        :param pulumi.Input[str] application_key: Azure Client Application Secret Key.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Name of Azure cloud account.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] subscription_id: Azure Subscription ID.
        :param pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] tenant_id: Azure Tenant ID.
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if application_key is not None:
            pulumi.set(__self__, "application_key", application_key)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if subscription_id is not None:
            pulumi.set(__self__, "subscription_id", subscription_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[str]]:
        """
        Azure Client Application ID.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_id", value)

    @property
    @pulumi.getter(name="applicationKey")
    def application_key(self) -> Optional[pulumi.Input[str]]:
        """
        Azure Client Application Secret Key.
        """
        return pulumi.get(self, "application_key")

    @application_key.setter
    def application_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_key", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]]]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Azure cloud account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> Optional[pulumi.Input[str]]:
        """
        Azure Subscription ID.
        """
        return pulumi.get(self, "subscription_id")

    @subscription_id.setter
    def subscription_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subscription_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AzureTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        Azure Tenant ID.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Azure(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 application_key: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subscription_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation Azure cloud account resource.

        ## Example Usage
        ### S

        The following example shows how to create an Azure cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.Azure("this",
            application_id="sample-application-id",
            application_key="sample-application=key",
            description="test cloud account",
            regions=["centralus"],
            subscription_id="sample-subscription-id",
            tenant_id="sample-tenant-id")
        ```

        ## Import

        To import the Azure cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/azure:Azure new_azure 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_id: Azure Client Application ID.
        :param pulumi.Input[str] application_key: Azure Client Application Secret Key.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Name of Azure cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] subscription_id: Azure Subscription ID.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] tenant_id: Azure Tenant ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AzureArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation Azure cloud account resource.

        ## Example Usage
        ### S

        The following example shows how to create an Azure cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.Azure("this",
            application_id="sample-application-id",
            application_key="sample-application=key",
            description="test cloud account",
            regions=["centralus"],
            subscription_id="sample-subscription-id",
            tenant_id="sample-tenant-id")
        ```

        ## Import

        To import the Azure cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/azure:Azure new_azure 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param AzureArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AzureArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[str]] = None,
                 application_key: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subscription_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AzureArgs.__new__(AzureArgs)

            if application_id is None and not opts.urn:
                raise TypeError("Missing required property 'application_id'")
            __props__.__dict__["application_id"] = application_id
            if application_key is None and not opts.urn:
                raise TypeError("Missing required property 'application_key'")
            __props__.__dict__["application_key"] = application_key
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if regions is None and not opts.urn:
                raise TypeError("Missing required property 'regions'")
            __props__.__dict__["regions"] = regions
            if subscription_id is None and not opts.urn:
                raise TypeError("Missing required property 'subscription_id'")
            __props__.__dict__["subscription_id"] = subscription_id
            __props__.__dict__["tags"] = tags
            if tenant_id is None and not opts.urn:
                raise TypeError("Missing required property 'tenant_id'")
            __props__.__dict__["tenant_id"] = tenant_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(Azure, __self__).__init__(
            'vra:cloudaccount/azure:Azure',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_id: Optional[pulumi.Input[str]] = None,
            application_key: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            subscription_id: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]]] = None,
            tenant_id: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Azure':
        """
        Get an existing Azure resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_id: Azure Client Application ID.
        :param pulumi.Input[str] application_key: Azure Client Application Secret Key.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureLinkArgs']]]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Name of Azure cloud account.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] subscription_id: Azure Subscription ID.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AzureTagArgs']]]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] tenant_id: Azure Tenant ID.
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AzureState.__new__(_AzureState)

        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["application_key"] = application_key
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["regions"] = regions
        __props__.__dict__["subscription_id"] = subscription_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tenant_id"] = tenant_id
        __props__.__dict__["updated_at"] = updated_at
        return Azure(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[str]:
        """
        Azure Client Application ID.
        """
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter(name="applicationKey")
    def application_key(self) -> pulumi.Output[str]:
        """
        Azure Client Application Secret Key.
        """
        return pulumi.get(self, "application_key")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.AzureLink']]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of Azure cloud account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> pulumi.Output[str]:
        """
        Azure Subscription ID.
        """
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.AzureTag']]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[str]:
        """
        Azure Tenant ID.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VSphereArgs', 'VSphere']

@pulumi.input_type
class VSphereArgs:
    def __init__(__self__, *,
                 hostname: pulumi.Input[str],
                 password: pulumi.Input[str],
                 regions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 username: pulumi.Input[str],
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 associated_cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dcid: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]]] = None):
        """
        The set of arguments for constructing a VSphere resource.
        :param pulumi.Input[str] hostname: IP address or FQDN of the vCenter Server. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[str] password: Password used to authenticate to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: A set of region names that are enabled for the cloud account.
        :param pulumi.Input[str] username: vSphere username used to authenticate to the cloud account.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] associated_cloud_account_ids: Cloud accounts associated with the cloud account.
        :param pulumi.Input[str] dcid: Identifier of a data collector vm deployed in the on premise infrastructure.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Name of the vSphere cloud account.
        :param pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]] tags: A set of tag keys and optional values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        pulumi.set(__self__, "hostname", hostname)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "regions", regions)
        pulumi.set(__self__, "username", username)
        if accept_self_signed_cert is not None:
            pulumi.set(__self__, "accept_self_signed_cert", accept_self_signed_cert)
        if associated_cloud_account_ids is not None:
            pulumi.set(__self__, "associated_cloud_account_ids", associated_cloud_account_ids)
        if dcid is not None:
            pulumi.set(__self__, "dcid", dcid)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Input[str]:
        """
        IP address or FQDN of the vCenter Server. The cloud proxy belongs on this vCenter.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: pulumi.Input[str]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[str]:
        """
        Password used to authenticate to the cloud account.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A set of region names that are enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[str]:
        """
        vSphere username used to authenticate to the cloud account.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> Optional[pulumi.Input[bool]]:
        """
        Accept self-signed certificate when connecting to the cloud account.
        """
        return pulumi.get(self, "accept_self_signed_cert")

    @accept_self_signed_cert.setter
    def accept_self_signed_cert(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "accept_self_signed_cert", value)

    @property
    @pulumi.getter(name="associatedCloudAccountIds")
    def associated_cloud_account_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Cloud accounts associated with the cloud account.
        """
        return pulumi.get(self, "associated_cloud_account_ids")

    @associated_cloud_account_ids.setter
    def associated_cloud_account_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "associated_cloud_account_ids", value)

    @property
    @pulumi.getter
    def dcid(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of a data collector vm deployed in the on premise infrastructure.
        """
        return pulumi.get(self, "dcid")

    @dcid.setter
    def dcid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dcid", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the vSphere cloud account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]]]:
        """
        A set of tag keys and optional values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _VSphereState:
    def __init__(__self__, *,
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 associated_cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 dcid: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hostname: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['VSphereLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VSphere resources.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] associated_cloud_account_ids: Cloud accounts associated with the cloud account.
        :param pulumi.Input[str] created_at: Date when  entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] dcid: Identifier of a data collector vm deployed in the on premise infrastructure.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] hostname: IP address or FQDN of the vCenter Server. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[Sequence[pulumi.Input['VSphereLinkArgs']]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Name of the vSphere cloud account.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] password: Password used to authenticate to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: A set of region names that are enabled for the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]] tags: A set of tag keys and optional values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] username: vSphere username used to authenticate to the cloud account.
        """
        if accept_self_signed_cert is not None:
            pulumi.set(__self__, "accept_self_signed_cert", accept_self_signed_cert)
        if associated_cloud_account_ids is not None:
            pulumi.set(__self__, "associated_cloud_account_ids", associated_cloud_account_ids)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if dcid is not None:
            pulumi.set(__self__, "dcid", dcid)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> Optional[pulumi.Input[bool]]:
        """
        Accept self-signed certificate when connecting to the cloud account.
        """
        return pulumi.get(self, "accept_self_signed_cert")

    @accept_self_signed_cert.setter
    def accept_self_signed_cert(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "accept_self_signed_cert", value)

    @property
    @pulumi.getter(name="associatedCloudAccountIds")
    def associated_cloud_account_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Cloud accounts associated with the cloud account.
        """
        return pulumi.get(self, "associated_cloud_account_ids")

    @associated_cloud_account_ids.setter
    def associated_cloud_account_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "associated_cloud_account_ids", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when  entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def dcid(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of a data collector vm deployed in the on premise infrastructure.
        """
        return pulumi.get(self, "dcid")

    @dcid.setter
    def dcid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "dcid", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[str]]:
        """
        IP address or FQDN of the vCenter Server. The cloud proxy belongs on this vCenter.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VSphereLinkArgs']]]]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VSphereLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the vSphere cloud account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        Password used to authenticate to the cloud account.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A set of region names that are enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]]]:
        """
        A set of tag keys and optional values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VSphereTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        vSphere username used to authenticate to the cloud account.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class VSphere(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 associated_cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dcid: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hostname: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VSphereTagArgs']]]]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation vSphere cloud account resource.

        ## Example Usage
        ### S

        The following example shows how to create a vSphere cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.VSphere("this",
            description="foobar",
            username=var["username"],
            password=var["password"],
            hostname=var["hostname"],
            dcid=var["vra_data_collector_id"],
            regions=var["regions"],
            associated_cloud_account_ids=[var["vra_cloud_account_nsxt_id"]],
            accept_self_signed_cert=True,
            tags=[vra.cloudaccount.VSphereTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the vSphere cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/vSphere:VSphere new_vsphere 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] associated_cloud_account_ids: Cloud accounts associated with the cloud account.
        :param pulumi.Input[str] dcid: Identifier of a data collector vm deployed in the on premise infrastructure.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] hostname: IP address or FQDN of the vCenter Server. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[str] name: Name of the vSphere cloud account.
        :param pulumi.Input[str] password: Password used to authenticate to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: A set of region names that are enabled for the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VSphereTagArgs']]]] tags: A set of tag keys and optional values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] username: vSphere username used to authenticate to the cloud account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VSphereArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation vSphere cloud account resource.

        ## Example Usage
        ### S

        The following example shows how to create a vSphere cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.VSphere("this",
            description="foobar",
            username=var["username"],
            password=var["password"],
            hostname=var["hostname"],
            dcid=var["vra_data_collector_id"],
            regions=var["regions"],
            associated_cloud_account_ids=[var["vra_cloud_account_nsxt_id"]],
            accept_self_signed_cert=True,
            tags=[vra.cloudaccount.VSphereTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the vSphere cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/vSphere:VSphere new_vsphere 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param VSphereArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VSphereArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
                 associated_cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 dcid: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hostname: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VSphereTagArgs']]]]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VSphereArgs.__new__(VSphereArgs)

            __props__.__dict__["accept_self_signed_cert"] = accept_self_signed_cert
            __props__.__dict__["associated_cloud_account_ids"] = associated_cloud_account_ids
            __props__.__dict__["dcid"] = dcid
            __props__.__dict__["description"] = description
            if hostname is None and not opts.urn:
                raise TypeError("Missing required property 'hostname'")
            __props__.__dict__["hostname"] = hostname
            __props__.__dict__["name"] = name
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = password
            if regions is None and not opts.urn:
                raise TypeError("Missing required property 'regions'")
            __props__.__dict__["regions"] = regions
            __props__.__dict__["tags"] = tags
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
            __props__.__dict__["created_at"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(VSphere, __self__).__init__(
            'vra:cloudaccount/vSphere:VSphere',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            accept_self_signed_cert: Optional[pulumi.Input[bool]] = None,
            associated_cloud_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            dcid: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            hostname: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VSphereLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VSphereTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'VSphere':
        """
        Get an existing VSphere resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] accept_self_signed_cert: Accept self-signed certificate when connecting to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] associated_cloud_account_ids: Cloud accounts associated with the cloud account.
        :param pulumi.Input[str] created_at: Date when  entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] dcid: Identifier of a data collector vm deployed in the on premise infrastructure.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] hostname: IP address or FQDN of the vCenter Server. The cloud proxy belongs on this vCenter.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VSphereLinkArgs']]]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Name of the vSphere cloud account.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] password: Password used to authenticate to the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: A set of region names that are enabled for the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VSphereTagArgs']]]] tags: A set of tag keys and optional values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] username: vSphere username used to authenticate to the cloud account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VSphereState.__new__(_VSphereState)

        __props__.__dict__["accept_self_signed_cert"] = accept_self_signed_cert
        __props__.__dict__["associated_cloud_account_ids"] = associated_cloud_account_ids
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["dcid"] = dcid
        __props__.__dict__["description"] = description
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["password"] = password
        __props__.__dict__["regions"] = regions
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["username"] = username
        return VSphere(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> pulumi.Output[Optional[bool]]:
        """
        Accept self-signed certificate when connecting to the cloud account.
        """
        return pulumi.get(self, "accept_self_signed_cert")

    @property
    @pulumi.getter(name="associatedCloudAccountIds")
    def associated_cloud_account_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        Cloud accounts associated with the cloud account.
        """
        return pulumi.get(self, "associated_cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when  entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def dcid(self) -> pulumi.Output[Optional[str]]:
        """
        Identifier of a data collector vm deployed in the on premise infrastructure.
        """
        return pulumi.get(self, "dcid")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[str]:
        """
        IP address or FQDN of the vCenter Server. The cloud proxy belongs on this vCenter.
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.VSphereLink']]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the vSphere cloud account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[str]:
        """
        Password used to authenticate to the cloud account.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[str]]:
        """
        A set of region names that are enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.VSphereTag']]:
        """
        A set of tag keys and optional values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when the entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[str]:
        """
        vSphere username used to authenticate to the cloud account.
        """
        return pulumi.get(self, "username")

